/**
 * 执行代码
 * 代码需放置在body最下部
 *
 * app: mui.plusReady(function() {执行代码}),需要将ga_params改为window['ga_params']
 * pc|wap: 执行代码
 *
 * @param {string} userCard 用户卡号或null,必填项
 * @param {string} uri 页面地址,APP必填项,PC和WAP不填
 * @param {string} protocol 统计系统提供的通信协议,选填,可选值有:http,https
 *
 * @example
 * var ga_params = [];
 * ga_params['uri'] = '/view/login/favor.html';
 * ga_params['userCard'] = '0010000000000';
 * ga_params['protocol'] = 'http';
 * (function() {
 *     var a = document.createElement("script");
 *     a.src = (ga_params['protocol'] === undefined ? 'http' : ga_params['protocol'])+"://tongji.guozhen.cn/ga.js?"+(Math.floor(Math.random()*2147483648).toString(36));
 *     a.id = "ga";
 *     var s = document.getElementsByTagName("script")[0]; 
 *     s.parentNode.insertBefore(a, s);
 * })();
 */
(function(){
    //平台对象
    gz_app = {};
    gz_pc = {};
    gz_wap = {};

    //平台对象初始化
    gz_app.name = 'app';
    gz_pc.name = 'pc';
    gz_wap.name = 'wap';

    //统计对象
    var ga = {};
    window['GA'] = ga;

    //统计对象初始化
        //统计版本号
    ga.version = '1.0.0';
        //统计图片地址
    ga.imageSrc = null;
        //外部数据
    ga.params = [];
        //cookie相关
    ga.cookie = {};
    ga.cookiePath = '/';
    ga.cookieExpiresLimit = 86400*365*50;
        //设置过期时间
        var tmp_date_date=new Date();
        var tmp_date_tmp = tmp_date_date.getTime()+86400*365*50*1000;
        tmp_date_date.setTime(tmp_date_tmp);
    ga.cookieExpiresTime = tmp_date_date.toGMTString();
        //这里使用根域名(.guozhen.cn),以便跨域存放(yeji.guozhen.cn,www.guozhen.cn),不考虑其他域名手缀如(com.cn,org.cn).
    ga.cookieDomain = '.' + window.location.host.split('.')[window.location.host.split('.').length-2]+'.'+window.location.host.split('.')[window.location.host.split('.').length-1];


    if (typeof plus !== "undefined") {
        ga.platform = gz_app;
    }else{

        if (location.pathname.indexOf('wap') > 0) {
            ga.platform = gz_wap;
        }else{
            ga.platform = gz_pc;
        }

    }

    ga.setImageSrc = function (){

        if (ga.params['protocol']  === undefined) {
            var gaProtocol = 'http';
        }else{
            var gaProtocol = ga.params['protocol'];
        }

        var rnd = Math.floor(Math.random()*2147483648).toString(36);

        switch (ga.platform.name){
            case 'app':
                if (typeof ONex.app_version !== "undefined" && ONex.app_version == 'pre-release') {
                    var gaHost = 'weidian.guozhen.cn';
                }else{
                    var gaHost = 'tongji.guozhen.cn';
                }
            break;
            default:
                if (location.host == 'www.guozhen.cn' || location.host == 'yeji.guozhen.cn') {
                    var gaHost = 'tongji.guozhen.cn';
                }else{
                    var gaHost = 'weidian.guozhen.cn';
                }   
            break;
        }

        ga.imageSrc = gaProtocol + '://'+gaHost+'/ga.gif'+ '?rand=' + rnd;
     
        // if (ga.params['protocol']  === undefined) {
        //     ga.imageSrc = 'http://tongji.guozhen.cn/ga.gif'+ '?rand=' + (Math.floor(Math.random()*2147483648).toString(36));
        // }else{
        //     ga.imageSrc = ga.params['protocol']+'://tongji.guozhen.cn/ga.gif'+ '?rand=' + (Math.floor(Math.random()*2147483648).toString(36));
        // }

    };

    ga.setParams = function (){
        ga.params = window['ga_params'] || ga_params;
    };

    //统计对象增加方法
    ga.setCookie = function(key, val){

        switch (ga.platform.name){
            case 'app':
                //app 调用js/glb/app.js中的setCookie方法
                setCookie(key, val, 0);
            break;
            default:
                document.cookie=key+"="+escape(val)+"; domain="+ga.cookieDomain+"; path="+ga.cookiePath+"; expires="+ga.cookieExpiresTime; 
            break;
        }

        return true;
    };

    ga.getCookie = function(key){

        switch (ga.platform.name){
            case 'app':
                //app 调用js/glb/app.js中的getCookie方法
                return getCookie(key);
            break;
            default:
                var cookieData = document.cookie.replace(/ /g, '').split(';');
                var row = [];
                for (var i in cookieData) {
                    row = cookieData[i].split('=');
                    if (row[0] == key) {
                        return unescape(row[1]);
                    }
                }    
            break;
        }

        return null;
    };
    
    ga.log = function(imageUrl){
        var object = new Image;
        window['GA_IMG'] = object;
        object.src = imageUrl;
    };

    ga.createUuid = function () {
        var s = [];
        var hexDigits = "0123456789abcdef";
        for (var i = 0; i < 36; i++) {
            s[i] = hexDigits.substr(Math.floor(Math.random() * 0x10), 1);
        }
        s[14] = "4";
        s[19] = hexDigits.substr((s[19] & 0x3) | 0x8, 1);
        s[8] = s[13] = s[18] = s[23] = "-";
     
        var uuid = s.join("");
        return uuid;
    };

    ga.setUuid = function(){
        
        switch (ga.platform.name){
            case 'app':
                ga.setCookie('GZ_UUID', plus.device.uuid);
            break;
            default:
                console.log(ga.getCookie('GZ_UUID'));
                if (ga.getCookie('GZ_UUID') === null) {
                    ga.setCookie('GZ_UUID', ga.createUuid());
                }
            break;
        }
        ga.cookie.gz_uuid = ga.getCookie('GZ_UUID');
        return true;
    };

    ga.setUserCard = function(){

        if (ga.params['userCard'] === undefined || ga.params['userCard'] === null) {
            ga.setCookie('GZ_USER_CARD', null);
        }else{
            ga.setCookie('GZ_USER_CARD', ga.params['userCard']);
        }

        ga.cookie.gz_user_card = ga.getCookie('GZ_USER_CARD');
        return true;
    };

    ga.setScreenSize = function(){
        
        switch (ga.platform.name){
            case 'app':
                ga.setCookie('GZ_SCREEN_SIZE', plus.screen.resolutionWidth*plus.screen.scale+","+plus.screen.resolutionHeight*plus.screen.scale);
            break;
            default:
                ga.setCookie('GZ_SCREEN_SIZE', window.screen.width+","+window.screen.height);
            break;
        }

        ga.cookie.gz_screen_size = ga.getCookie('GZ_SCREEN_SIZE');
        return true;
    };

    ga.setPlatform = function(){
        ga.setCookie('GZ_PLATFORM', ga.platform.name.toUpperCase());
        ga.cookie.gz_platform = ga.getCookie('GZ_PLATFORM');
        return true;
    };

    ga.setUri = function(){

        switch (ga.platform.name){
            case 'app':
                if (ga.params['uri'] === undefined || ga.params['uri'] === null) {
                    ga.setCookie('GZ_URI', null);
                }else{
                    ga.setCookie('GZ_URI', ga.params['uri']);
                }
            break;
            default:
                ga.setCookie('GZ_URI', window.location.href);
            break;
        }

        ga.cookie.gz_uri = ga.getCookie('GZ_URI');
        return true;       
    };

    ga.setStayTime = function(){
        ga.setCookie('GZ_STAY_TIME', 0); //先0,在后台修改
        ga.cookie.gz_stay_time = ga.getCookie('GZ_STAY_TIME');
        return true;
    };

    ga.setReferrer = function(){

        switch (ga.platform.name){
            case 'app':
                ga.setCookie('GZ_REFERRER', ga.getCookie('GZ_URI') || null);
            break;
            default:
                ga.setCookie('GZ_REFERRER', document.referrer || null);
            break;
        }

        ga.cookie.gz_referrer = ga.getCookie('GZ_REFERRER');
        return true;
    };

    ga.setAction = function(){
        ga.setCookie('GZ_ACTION', 'view');
        ga.cookie.gz_action = ga.getCookie('GZ_ACTION');
        return true;
    };

    ga.setVersion = function(){
        ga.setCookie('GZ_VERSION', ga.version);
        ga.cookie.gz_version = ga.getCookie('GZ_VERSION');
        return true;
    };

    ga.setPhoneDeviceVendor = function(){
        switch (ga.platform.name){
            case 'app':
                ga.setCookie('GZ_PHONE_DEVICE_VENDOR', plus.device.vendor);
            break;
            default:
                ga.setCookie('GZ_PHONE_DEVICE_VENDOR', null);
            break;
        }
        ga.cookie.gz_phone_device_vendor = ga.getCookie('GZ_PHONE_DEVICE_VENDOR');
        return true;
    };

    ga.setPhoneDeviceModel = function(){
        switch (ga.platform.name){
            case 'app':
                ga.setCookie('GZ_PHONE_DEVICE_MODEL', plus.device.model);
            break;
            default:
                ga.setCookie('GZ_PHONE_DEVICE_MODEL', null);
            break;
        }
        ga.cookie.gz_phone_device_model = ga.getCookie('GZ_PHONE_DEVICE_MODEL');
        return true;
    };

    ga.setPhoneOsName = function(){
        switch (ga.platform.name){
            case 'app':
                ga.setCookie('GZ_PHONE_OS_NAME', plus.device.model);
            break;
            default:
                ga.setCookie('GZ_PHONE_OS_NAME', null);
            break;
        }
        ga.cookie.gz_phone_os_name = ga.getCookie('GZ_PHONE_OS_NAME');
        return true;
    };

    ga.setPhoneOsVersion = function(){
        switch (ga.platform.name){
            case 'app':
                ga.setCookie('GZ_PHONE_OS_VERSION', plus.os.version);
            break;
            default:
                ga.setCookie('GZ_PHONE_OS_VERSION', null);
            break;
        }
        ga.cookie.gz_phone_os_version = ga.getCookie('GZ_PHONE_OS_VERSION');
        return true;
    };

    //配置
    ga.setImageSrc();
    ga.setParams();

    //收集通用信息
    ga.setUuid();
    ga.setUserCard();
    ga.setScreenSize();
    ga.setPlatform();
        //先referrer再uri
    ga.setReferrer();
    ga.setUri();
    ga.setStayTime();
    ga.setAction();
    ga.setVersion();

    //收集手机信息
    ga.setPhoneDeviceVendor();
    ga.setPhoneDeviceModel();
    ga.setPhoneOsName();
    ga.setPhoneOsVersion();

    //整理信息
    var tmp = [];
    var queryString = '';
    var index = 0;
    for(var i in ga.cookie){
        tmp[index++] = i+"="+(ga.cookie[i] === 'null' ? '' : ga.cookie[i]);

        //如果未拿到参数,即数据出错,则不统计
        if(i == 'gz_action' && (ga.cookie[i] == 'null' || ga.cookie[i] == '' || ga.cookie[i] == null)){
            return false;
        }
    }

    if (tmp.length > 0) {
        queryString = '&' + tmp.join('&');
    }

    //记录
    (function(){
        ga.log(ga.imageSrc+queryString);
    })();

})();